@@ -4,7 +4,7 @@ set -ex
 WORKDIR=$(readlink -f $0 | xargs dirname)
 BUILDDIR="$WORKDIR/tinyipabuild"
 BUILD_AND_INSTALL_TINYIPA=${BUILD_AND_INSTALL_TINYIPA:-false}
-TINYCORE_MIRROR_URL=${TINYCORE_MIRROR_URL-"http://repo.tinycorelinux.net/"}
+TINYCORE_MIRROR_URL=${TINYCORE_MIRROR_URL:-"http://repo.tinycorelinux.net/"}
 
 CHROOT_PATH="/tmp/overides:/usr/local/sbin:/usr/local/bin:/apps/bin:/usr/sbin:/usr/bin:/sbin:/bin"
 CHROOT_CMD="sudo chroot $BUILDDIR /usr/bin/env -i PATH=$CHROOT_PATH http_proxy=$http_proxy https_proxy=$https_proxy no_proxy=$no_proxy"
@@ -65,6 +65,9 @@ cd ../..
 rm -rf *.egg-info
 python setup.py sdist --dist-dir "$BUILDDIR/tmp/localpip" --quiet
 cp requirements.txt $BUILDDIR/tmp/ipa-requirements.txt
+
+imagebuild/common/generate_upper_constraints.sh upper-constraints.txt
+cp upper-constraints.txt $BUILDDIR/tmp/upper-constraints.txt
 cd $WORKDIR
 
 sudo cp /etc/resolv.conf $BUILDDIR/etc/resolv.conf
@@ -88,10 +91,10 @@ done < $WORKDIR/build_files/buildreqs.lst
 # Build python wheels
 $CHROOT_CMD python /tmp/get-pip.py
 $CHROOT_CMD pip install pbr
-$CHROOT_CMD pip wheel --wheel-dir /tmp/wheels setuptools
-$CHROOT_CMD pip wheel --wheel-dir /tmp/wheels pip
-$CHROOT_CMD pip wheel --wheel-dir /tmp/wheels -r /tmp/ipa-requirements.txt
-$CHROOT_CMD pip wheel --no-index --pre --wheel-dir /tmp/wheels --find-links=/tmp/localpip --find-links=/tmp/wheels ironic-python-agent
+$CHROOT_CMD pip wheel -c /tmp/upper-constraints.txt --wheel-dir /tmp/wheels setuptools
+$CHROOT_CMD pip wheel -c /tmp/upper-constraints.txt --wheel-dir /tmp/wheels pip
+$CHROOT_CMD pip wheel -c /tmp/upper-constraints.txt --wheel-dir /tmp/wheels -r /tmp/ipa-requirements.txt
+$CHROOT_CMD pip wheel -c /tmp/upper-constraints.txt --no-index --pre --wheel-dir /tmp/wheels --find-links=/tmp/localpip --find-links=/tmp/wheels ironic-python-agent
 
 # Build tgt
 rm -rf $WORKDIR/build_files/tgt.tcz
